Class: OctaSpace::Resources::Accounts
- Defined in:
- lib/octaspace/resources/accounts.rb
Overview
Account-related API endpoints
Instance Method Summary collapse
-
#balance ⇒ OctaSpace::Response
Fetch the authenticated user’s balance GET /accounts/balance.
-
#generate_wallet ⇒ OctaSpace::Response
Generate / create a new wallet for the authenticated user POST /accounts.
-
#profile ⇒ OctaSpace::Response
Fetch the authenticated user’s profile GET /accounts.
Methods inherited from Base
Constructor Details
This class inherits a constructor from OctaSpace::Resources::Base
Instance Method Details
#balance ⇒ OctaSpace::Response
Fetch the authenticated user’s balance GET /accounts/balance
21 22 23 |
# File 'lib/octaspace/resources/accounts.rb', line 21 def balance get("/accounts/balance") end |
#generate_wallet ⇒ OctaSpace::Response
Generate / create a new wallet for the authenticated user POST /accounts
28 29 30 |
# File 'lib/octaspace/resources/accounts.rb', line 28 def generate_wallet post("/accounts") end |
#profile ⇒ OctaSpace::Response
Fetch the authenticated user’s profile GET /accounts
14 15 16 |
# File 'lib/octaspace/resources/accounts.rb', line 14 def profile get("/accounts") end |