Class: OctaSpace::Resources::Services
- Defined in:
- lib/octaspace/resources/services.rb,
lib/octaspace/resources/services/vpn.rb,
lib/octaspace/resources/services/render.rb,
lib/octaspace/resources/services/session_proxy.rb,
lib/octaspace/resources/services/machine_rental.rb
Overview
Services namespace — aggregates MR, VPN, Render subresources and provides the session proxy pattern
Defined Under Namespace
Classes: MachineRental, Render, SessionProxy, Vpn
Instance Attribute Summary collapse
-
#mr ⇒ Object
readonly
Returns the value of attribute mr.
-
#render ⇒ Object
readonly
Returns the value of attribute render.
-
#vpn ⇒ Object
readonly
Returns the value of attribute vpn.
Instance Method Summary collapse
-
#initialize(transport) ⇒ Services
constructor
A new instance of Services.
-
#session(uuid) ⇒ OctaSpace::Resources::Services::SessionProxy
Return a proxy object for operations on a specific session.
Constructor Details
#initialize(transport) ⇒ Services
Returns a new instance of Services.
19 20 21 22 23 24 |
# File 'lib/octaspace/resources/services.rb', line 19 def initialize(transport) super @mr = Services::MachineRental.new(transport) @vpn = Services::Vpn.new(transport) @render = Services::Render.new(transport) end |
Instance Attribute Details
#mr ⇒ Object (readonly)
Returns the value of attribute mr.
17 18 19 |
# File 'lib/octaspace/resources/services.rb', line 17 def mr @mr end |
#render ⇒ Object (readonly)
Returns the value of attribute render.
17 18 19 |
# File 'lib/octaspace/resources/services.rb', line 17 def render @render end |
#vpn ⇒ Object (readonly)
Returns the value of attribute vpn.
17 18 19 |
# File 'lib/octaspace/resources/services.rb', line 17 def vpn @vpn end |
Instance Method Details
#session(uuid) ⇒ OctaSpace::Resources::Services::SessionProxy
Return a proxy object for operations on a specific session
29 30 31 |
# File 'lib/octaspace/resources/services.rb', line 29 def session(uuid) Services::SessionProxy.new(transport, uuid) end |